window.Gleam.initSearch([{"doc":"gleamy_bench","title":"gleamy_bench","content":"# gleamy_bench\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamy_bench)](https://hex.pm/packages/gleamy_bench)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamy_bench/)\n\nA library for benchmarking gleam code.\n\n# How To\n\n```gleam\nimport gleamy/bench\n\n// ...\n\nbench.run(\n  [\n    bench.Input(&quot;pre-sorted list&quot;, list.range(1, 100_000)),\n    bench.Input(&quot;reversed list&quot;, list.reverse(list.range(1, 100_000))),\n  ],\n  [bench.Function(&quot;list.sort()&quot;, sort_int)],\n  [bench.Duration(1000), bench.Warmup(100)],\n)\n|&gt; bench.table([bench.IPS, bench.Min, bench.P(99)])\n|&gt; io.println()\n```\n\nA benchmark is defined by giving a list of inputs and a list of functions to run on those inputs. Each input + function combination will be timed.\n\nThe given inputs should all be the same type, and the functions should all accept that type as the only argument.\n\nThe `run` function actually runs the benchmark and collects the results. It also accepts a list of options to change default behaviour, for example `Duration(1000)` is used to change how long each function is run repeatedly when collecting results (in milliseconds). This list is optional and can be empty if you have no need to change the defaults.\n\nThe `table` function makes a table out of the results. You can choose the list of statistics you would like to include in the table.\n\nThe output for this example looks like the following.\n\n```\nInput                   Function                           IPS             Min             P99\npre-sorted list         list.sort()                    37.8532         22.4190         31.3593\nreversed list           list.sort()                    34.0101         27.0734         31.0618\n```\n\n## Function with additional setup\n\nSometimes you need to do some additional setup before you can call your function, instead of having it called directly with the input data.\nFor this use case you can use bench.SetupFunction\n\n`SetupFunction(label: String, setup_function: fn(a) -&gt; fn(a) -&gt; b)`\n\nThe setup function is executed once at the start of the run, and should return the function that will be benchmarked.\nBoth the setup function and the benchmark function will be passed the input data.\n\nFor example, you might be testing the speed of a certain operation on a range of data structures.\nTo do this you will need to create each data structure beforehand with the given input data so you can run the operation on it.\n\n```gleam\nbench.run(\n  [\n    bench.Input(&quot;100&quot;, list.range(1, 100)),\n    bench.Input(&quot;1000&quot;, list.reverse(list.range(1, 1000))),\n  ],\n  [\n    bench.SetupFunction(&quot;dict.get&quot;, fn(items) {\n      // This section will not be measured in the benchmark.\n      // We fill a dictionary with the input items to use later.\n      let d = list.fold(items, dict.new(), fn(d, i) {\n        dict.insert(d, i, i)\n      })m\n\n      // The returned function will be measured for the benchmark.\n      // It tries to &quot;get&quot; each item in the input from the dictionary.\n      fn(items) {\n        list.each(items, fn(i) { dict.get(d, i) })\n      }\n    })\n\n    // ...\n  ],\n  [bench.Duration(1000), bench.Warmup(100)],\n)\n```\n\n## Contributing\n\nSuggestions and pull requests are welcome!\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add gleamy_bench\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gleamy_bench&gt;.\n","url":"index.html"},{"doc":"gleamy/bench","title":"BenchResults","content":"pub type BenchResults {\n  BenchResults(options: Options, sets: List(Set))\n}\n\nBenchResults(options: Options, sets: List(Set))\n\n\nSynonyms:\ngleamy/bench.BenchResults\ngleamy/bench BenchResults","url":"gleamy/bench.html#BenchResults"},{"doc":"gleamy/bench","title":"Function","content":"pub type Function(a, b) {\n  Function(label: String, function: fn(a) -&gt; b)\n  SetupFunction(\n    label: String,\n    setup_function: fn(a) -&gt; fn(a) -&gt; b,\n  )\n}\n\nFunction(label: String, function: fn(a) -&gt; b)\n\n\nSetupFunction(label: String, setup_function: fn(a) -&gt; fn(a) -&gt; b)\n\n\nSynonyms:\ngleamy/bench.Function\ngleamy/bench Function","url":"gleamy/bench.html#Function"},{"doc":"gleamy/bench","title":"Input","content":"pub type Input(a) {\n  Input(label: String, value: a)\n}\n\nInput(label: String, value: a)\n\n\nSynonyms:\ngleamy/bench.Input\ngleamy/bench Input","url":"gleamy/bench.html#Input"},{"doc":"gleamy/bench","title":"Option","content":"pub type Option {\n  Warmup(ms: Int)\n  Duration(ms: Int)\n  Decimals(n: Int)\n  Quiet\n}\n\nWarmup(ms: Int)\n\n\nDuration(ms: Int)\n\n\nDecimals(n: Int)\n\n\nQuiet\n\n\nSynonyms:\ngleamy/bench.Option\ngleamy/bench Option","url":"gleamy/bench.html#Option"},{"doc":"gleamy/bench","title":"Options","content":"pub type Options {\n  Options(warmup: Int, duration: Int, decimals: Int, quiet: Bool)\n}\n\nOptions(warmup: Int, duration: Int, decimals: Int, quiet: Bool)\n\n\nSynonyms:\ngleamy/bench.Options\ngleamy/bench Options","url":"gleamy/bench.html#Options"},{"doc":"gleamy/bench","title":"Set","content":"pub type Set {\n  Set(input: String, function: String, reps: List(Float))\n}\n\nSet(input: String, function: String, reps: List(Float))\n\n\nSynonyms:\ngleamy/bench.Set\ngleamy/bench Set","url":"gleamy/bench.html#Set"},{"doc":"gleamy/bench","title":"Stat","content":"pub type Stat {\n  P(Int)\n  IPS\n  Min\n  Max\n  Mean\n  SD\n  SDPercent\n  Stat(name: String, calculate: fn(Set) -&gt; Float)\n}\n\nP(Int)\n\n\nIPS\n\n\nMin\n\n\nMax\n\n\nMean\n\n\nSD\n\n\nSDPercent\n\n\nStat(name: String, calculate: fn(Set) -&gt; Float)\n\n\nSynonyms:\ngleamy/bench.Stat\ngleamy/bench Stat","url":"gleamy/bench.html#Stat"},{"doc":"gleamy/bench","title":"do_repeat","content":"pub fn do_repeat(n: Int, input: a, fun: fn(a) -&gt; b) -&gt; Nil\n\nSynonyms:\ngleamy/bench.do_repeat\ngleamy/bench do_repeat","url":"gleamy/bench.html#do_repeat"},{"doc":"gleamy/bench","title":"now","content":"pub fn now() -&gt; Float\n timestamp in milliseconds\nSynonyms:\ngleamy/bench.now\ngleamy/bench now","url":"gleamy/bench.html#now"},{"doc":"gleamy/bench","title":"repeat","content":"pub fn repeat(n: Int, fun: fn(a) -&gt; b) -&gt; fn(a) -&gt; Nil\n\nSynonyms:\ngleamy/bench.repeat\ngleamy/bench repeat","url":"gleamy/bench.html#repeat"},{"doc":"gleamy/bench","title":"run","content":"pub fn run(\n  inputs: List(Input(a)),\n  functions: List(Function(a, b)),\n  options: List(Option),\n) -&gt; BenchResults\n\nSynonyms:\ngleamy/bench.run\ngleamy/bench run","url":"gleamy/bench.html#run"},{"doc":"gleamy/bench","title":"table","content":"pub fn table(result: BenchResults, stats: List(Stat)) -&gt; String\n\nSynonyms:\ngleamy/bench.table\ngleamy/bench table","url":"gleamy/bench.html#table"},{"doc":"gleamy/bench","title":"gleamy/bench","content":"","url":"gleamy/bench.html"},{"doc":"gleamy_bench_example","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ngleamy_bench_example.main\ngleamy_bench_example main","url":"gleamy_bench_example.html#main"},{"doc":"gleamy_bench_example","title":"gleamy_bench_example","content":"","url":"gleamy_bench_example.html"}]);